// This is a script that was created to run in Tabular Editor from the C# Script window.
// The purpose of the script is to create and organize "SUM" measures from numerical columns you select in the model.
// 
// In Tabular Editor, you can press "CTRL+Z" to undo any changes made by scripting (or manually)

// Config
var _agg = "Sum";

// Creates a SUM measure for every currently selected column and hide the column.
foreach(var c in Selected.Columns)
{  
    // Add the measures to the newly created measure table
    var m = c.Table.AddMeasure(
        // Measure name
        $"Total {c.Name}",

        // Measure DAX
        FormatDax( $"{_agg.ToUpper()}( {c.DaxObjectFullName} )", shortFormat:true),
        $"\\Measures\\{_agg}"
    );

    // Set the format string on the new measure:
    m.FormatString = "#,##0";

    // Provide some documentation:
    m.Description = $"This measure is the {_agg} of {c.DaxObjectFullName}";

    // Hide the base column:
    c.IsHidden = true;

    // Set Summarization to 'None':
    c.SummarizeBy = AggregateFunction.None;

    // Add columns to display folder
    c.DisplayFolder = "\\Columns\\0. Facts";

}

Info ( $"Created {Convert.ToString(Selected.Columns.Count()) } measures." );