// This is a script that was created to run in Tabular Editor from the C# Script window.
// The purpose of the script is to create measures that use the dynamic currency conversion pattern.
// The script also sets the dynamic format string of the measure. It doesn't set the "delta" dynamic format string (+/-).
// See : https://www.daxpatterns.com/currency-conversion/
// 
// In Tabular Editor, you can press "CTRL+Z" to undo any changes made by scripting (or manually)

// Select the currency column from the Fact table that has the column the measure is aggregating.
var _RateColumn = SelectColumn(Model.AllColumns.Where(c => c.Name.Contains("Exchange")), null, "Select rate column in exchange rate table:");

foreach ( var _m in Selected.Measures )
    {

// DAX code for the dynamic currency conversion
    string _MeasureDAX = @"
IF (
    HASONEVALUE ( 'Target Currency'[Currency] ),
    VAR AggregatedSalesInCurrency =
        ADDCOLUMNS (
            SUMMARIZE (" +
                _m.Table.Name + @",
                'Date'[Date],
                'Source Currency'[Currency]
            ),
            ""@Amount"", " + _m.DaxObjectFullName + @",
            ""@Rate"", CALCULATE ( SELECTEDVALUE ( " + _RateColumn.DaxObjectFullName + @" ) )
        )
    VAR Result =
        SUMX (
            AggregatedSalesInCurrency,
            IF (
                NOT ( ISBLANK ( [@Rate] ) ),
                [@Amount] * [@Rate],
                ERROR ( ""Missing conversion rate"" )
            )
        )
    RETURN
        Result
)";

// Add the new dynamic currency conversion measure to the model
    var _NewMeasure = _m.Table.AddMeasure(
    _m.Name + " (Selected Currency)",
    _MeasureDAX,
    "Measures\\Currency Conversion" );

// Add the dynamic measure format string
    _NewMeasure.FormatStringExpression = @"SELECTEDVALUE( 'Target Currency'[Format String] )";
    }

// Tell the user that it's done and they can now go get a coffee, beer, aryan, sake, or other suitable beverage.
Info( "Successfully added measures.");

